/****************************************************************************
** Meta object code from reading C++ file 'containmentitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.7.3/src/plasmaquick/plasmoid/containmentitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'containmentitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ContainmentItemE_t {};
} // unnamed namespace

template <> constexpr inline auto ContainmentItem::qt_create_metaobjectdata<qt_meta_tag_ZN15ContainmentItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ContainmentItem",
        "appletsChanged",
        "",
        "drawWallpaperChanged",
        "actionsChanged",
        "editModeChanged",
        "wallpaperItemChanged",
        "isLoadingChanged",
        "createApplet",
        "Plasma::Applet*",
        "plugin",
        "QVariantList",
        "args",
        "QRectF",
        "geom",
        "itemFor",
        "AppletQuickItem*",
        "applet",
        "processMimeData",
        "QMimeData*",
        "data",
        "x",
        "y",
        "KIO::DropJob*",
        "dropJob",
        "containmentItemAt",
        "mapFromApplet",
        "QPointF",
        "mapToApplet",
        "adjustToAvailableScreenRegion",
        "w",
        "h",
        "openContextMenu",
        "globalPos",
        "wallpaper",
        "WallpaperItem*",
        "loading"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'appletsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'drawWallpaperChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editModeChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wallpaperItemChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isLoadingChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createApplet'
        QtMocHelpers::SlotData<Plasma::Applet *(const QString &, const QVariantList &, const QRectF &)>(8, 2, QMC::AccessPrivate, 0x80000000 | 9, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'itemFor'
        QtMocHelpers::MethodData<AppletQuickItem *(Plasma::Applet *) const>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 9, 17 },
        }}),
        // Method 'processMimeData'
        QtMocHelpers::MethodData<void(QMimeData *, int, int, KIO::DropJob *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Method 'processMimeData'
        QtMocHelpers::MethodData<void(QMimeData *, int, int)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Method 'processMimeData'
        QtMocHelpers::MethodData<void(QObject *, int, int, KIO::DropJob *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Method 'processMimeData'
        QtMocHelpers::MethodData<void(QObject *, int, int)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QObjectStar, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Method 'containmentItemAt'
        QtMocHelpers::MethodData<QObject *(int, int)>(25, 2, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Method 'mapFromApplet'
        QtMocHelpers::MethodData<QPointF(Plasma::Applet *, int, int)>(26, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 9, 17 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Method 'mapToApplet'
        QtMocHelpers::MethodData<QPointF(Plasma::Applet *, int, int)>(28, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 9, 17 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Method 'adjustToAvailableScreenRegion'
        QtMocHelpers::MethodData<QPointF(int, int, int, int) const>(29, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 },
        }}),
        // Method 'openContextMenu'
        QtMocHelpers::MethodData<void(const QPointF &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'wallpaper'
        QtMocHelpers::PropertyData<WallpaperItem*>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ContainmentItem, qt_meta_tag_ZN15ContainmentItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ContainmentItem::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmoidItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ContainmentItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ContainmentItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ContainmentItemE_t>.metaTypes,
    nullptr
} };

void ContainmentItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ContainmentItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->appletsChanged(); break;
        case 1: _t->drawWallpaperChanged(); break;
        case 2: _t->actionsChanged(); break;
        case 3: _t->editModeChanged(); break;
        case 4: _t->wallpaperItemChanged(); break;
        case 5: _t->isLoadingChanged(); break;
        case 6: { Plasma::Applet* _r = _t->createApplet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Plasma::Applet**>(_a[0]) = std::move(_r); }  break;
        case 7: { AppletQuickItem* _r = _t->itemFor((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<AppletQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 8: _t->processMimeData((*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KIO::DropJob*>>(_a[4]))); break;
        case 9: _t->processMimeData((*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 10: _t->processMimeData((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KIO::DropJob*>>(_a[4]))); break;
        case 11: _t->processMimeData((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 12: { QObject* _r = _t->containmentItemAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 13: { QPointF _r = _t->mapFromApplet((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 14: { QPointF _r = _t->mapToApplet((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 15: { QPointF _r = _t->adjustToAvailableScreenRegion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->openContextMenu((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ContainmentItem::*)()>(_a, &ContainmentItem::appletsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentItem::*)()>(_a, &ContainmentItem::drawWallpaperChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentItem::*)()>(_a, &ContainmentItem::actionsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentItem::*)()>(_a, &ContainmentItem::editModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentItem::*)()>(_a, &ContainmentItem::wallpaperItemChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentItem::*)()>(_a, &ContainmentItem::isLoadingChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<WallpaperItem**>(_v) = _t->wallpaperItem(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isLoading(); break;
        default: break;
        }
    }
}

const QMetaObject *ContainmentItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ContainmentItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ContainmentItemE_t>.strings))
        return static_cast<void*>(this);
    return PlasmoidItem::qt_metacast(_clname);
}

int ContainmentItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmoidItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ContainmentItem::appletsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ContainmentItem::drawWallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ContainmentItem::actionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ContainmentItem::editModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ContainmentItem::wallpaperItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ContainmentItem::isLoadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
