/****************************************************************************
** Meta object code from reading C++ file 'applet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.7.3/src/plasma/applet.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'applet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Plasma6AppletE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma::Applet::qt_create_metaobjectdata<qt_meta_tag_ZN6Plasma6AppletE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma::Applet",
        "QML.ListPropertyAssignBehavior",
        "Replace",
        "immutabilityChanged",
        "",
        "Plasma::Types::ImmutabilityType",
        "immutable",
        "statusChanged",
        "Plasma::Types::ItemStatus",
        "status",
        "destroyedChanged",
        "destroyed",
        "titleChanged",
        "title",
        "iconChanged",
        "icon",
        "busyChanged",
        "busy",
        "backgroundHintsChanged",
        "userBackgroundHintsChanged",
        "effectiveBackgroundHintsChanged",
        "globalShortcutChanged",
        "QKeySequence",
        "sequence",
        "configNeedsSaving",
        "userConfiguringChanged",
        "configuring",
        "contextualActionsAboutToShow",
        "activated",
        "secondaryActivated",
        "appletDeleted",
        "Plasma::Applet*",
        "applet",
        "formFactorChanged",
        "Plasma::Types::FormFactor",
        "formFactor",
        "locationChanged",
        "Plasma::Types::Location",
        "location",
        "containmentDisplayHintsChanged",
        "Plasma::Types::ContainmentDisplayHints",
        "hints",
        "configurationRequiredChanged",
        "needsConfig",
        "reason",
        "hasConfigurationInterfaceChanged",
        "hasConfiguration",
        "constraintHintsChanged",
        "Plasma::Applet::ConstraintHints",
        "constraintHints",
        "containmentChanged",
        "Plasma::Containment*",
        "containment",
        "contextualActionsChanged",
        "QList<QAction*>",
        "actions",
        "internalActionsChanged",
        "setLaunchErrorMessage",
        "setImmutability",
        "Types::ImmutabilityType",
        "destroy",
        "setStatus",
        "Types::ItemStatus",
        "stat",
        "configChanged",
        "flushPendingConstraintsEvents",
        "init",
        "cleanUpAndDelete",
        "askDestroy",
        "propagateConfigChanged",
        "requestConfiguration",
        "setInternalAction",
        "name",
        "QAction*",
        "action",
        "internalAction",
        "removeInternalAction",
        "id",
        "immutability",
        "containmentDisplayHints",
        "userConfiguring",
        "backgroundHints",
        "Plasma::Types::BackgroundHints",
        "userBackgroundHints",
        "effectiveBackgroundHints",
        "configuration",
        "KConfigPropertyMap*",
        "globalShortcut",
        "configurationRequired",
        "hasConfigurationInterface",
        "metaData",
        "KPluginMetaData",
        "contextualActions",
        "QQmlListProperty<QAction>",
        "isContainment",
        "pluginName",
        "Constraint",
        "NoConstraint",
        "FormFactorConstraint",
        "LocationConstraint",
        "ScreenConstraint",
        "ImmutableConstraint",
        "StartupCompletedConstraint",
        "UiReadyConstraint",
        "AllConstraints",
        "ConstraintHints",
        "ConstraintHint",
        "NoHint",
        "CanFillArea",
        "MarginAreasSeparator"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'immutabilityChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::ImmutabilityType)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::ItemStatus)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'destroyedChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'backgroundHintsChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userBackgroundHintsChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'effectiveBackgroundHintsChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalShortcutChanged'
        QtMocHelpers::SignalData<void(const QKeySequence &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'configNeedsSaving'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userConfiguringChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Signal 'contextualActionsAboutToShow'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activated'
        QtMocHelpers::SignalData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'secondaryActivated'
        QtMocHelpers::SignalData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appletDeleted'
        QtMocHelpers::SignalData<void(Plasma::Applet *)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Signal 'formFactorChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::FormFactor)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::Location)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Signal 'containmentDisplayHintsChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::ContainmentDisplayHints)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Signal 'configurationRequiredChanged'
        QtMocHelpers::SignalData<void(bool, const QString &)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 43 }, { QMetaType::QString, 44 },
        }}),
        // Signal 'hasConfigurationInterfaceChanged'
        QtMocHelpers::SignalData<void(bool)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 46 },
        }}),
        // Signal 'constraintHintsChanged'
        QtMocHelpers::SignalData<void(Plasma::Applet::ConstraintHints)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Signal 'containmentChanged'
        QtMocHelpers::SignalData<void(Plasma::Containment *)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Signal 'contextualActionsChanged'
        QtMocHelpers::SignalData<void(const QList<QAction*> &)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Signal 'internalActionsChanged'
        QtMocHelpers::SignalData<void(const QList<QAction*> &)>(56, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'setLaunchErrorMessage'
        QtMocHelpers::SlotData<void(const QString &)>(57, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'setLaunchErrorMessage'
        QtMocHelpers::SlotData<void()>(57, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setImmutability'
        QtMocHelpers::SlotData<void(const Types::ImmutabilityType)>(58, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 6 },
        }}),
        // Slot 'destroy'
        QtMocHelpers::SlotData<void()>(60, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setStatus'
        QtMocHelpers::SlotData<void(const Types::ItemStatus)>(61, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
        // Slot 'configChanged'
        QtMocHelpers::SlotData<void()>(64, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'flushPendingConstraintsEvents'
        QtMocHelpers::SlotData<void()>(65, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(66, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanUpAndDelete'
        QtMocHelpers::SlotData<void()>(67, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'askDestroy'
        QtMocHelpers::SlotData<void()>(68, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'globalShortcutChanged'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'propagateConfigChanged'
        QtMocHelpers::SlotData<void()>(69, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'requestConfiguration'
        QtMocHelpers::SlotData<void()>(70, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'setInternalAction'
        QtMocHelpers::MethodData<void(const QString &, QAction *)>(71, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 72 }, { 0x80000000 | 73, 74 },
        }}),
        // Method 'internalAction'
        QtMocHelpers::MethodData<QAction *(const QString &) const>(75, 4, QMC::AccessPublic, 0x80000000 | 73, {{
            { QMetaType::QString, 72 },
        }}),
        // Method 'removeInternalAction'
        QtMocHelpers::MethodData<void(const QString &)>(76, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 72 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<uint>(77, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'formFactor'
        QtMocHelpers::PropertyData<Plasma::Types::FormFactor>(35, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 16),
        // property 'location'
        QtMocHelpers::PropertyData<Plasma::Types::Location>(38, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 17),
        // property 'status'
        QtMocHelpers::PropertyData<Plasma::Types::ItemStatus>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'immutability'
        QtMocHelpers::PropertyData<Plasma::Types::ImmutabilityType>(78, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'immutable'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'containmentDisplayHints'
        QtMocHelpers::PropertyData<Plasma::Types::ContainmentDisplayHints>(79, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 18),
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'userConfiguring'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'backgroundHints'
        QtMocHelpers::PropertyData<Plasma::Types::BackgroundHints>(81, 0x80000000 | 82, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 6),
        // property 'userBackgroundHints'
        QtMocHelpers::PropertyData<Plasma::Types::BackgroundHints>(83, 0x80000000 | 82, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7),
        // property 'effectiveBackgroundHints'
        QtMocHelpers::PropertyData<Plasma::Types::BackgroundHints>(84, 0x80000000 | 82, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 8),
        // property 'configuration'
        QtMocHelpers::PropertyData<KConfigPropertyMap*>(85, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'globalShortcut'
        QtMocHelpers::PropertyData<QKeySequence>(87, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'configurationRequired'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'hasConfigurationInterface'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'constraintHints'
        QtMocHelpers::PropertyData<Plasma::Applet::ConstraintHints>(49, 0x80000000 | 48, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 21),
        // property 'metaData'
        QtMocHelpers::PropertyData<KPluginMetaData>(90, 0x80000000 | 91, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'containment'
        QtMocHelpers::PropertyData<Plasma::Containment*>(52, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 22),
        // property 'contextualActions'
        QtMocHelpers::PropertyData<QQmlListProperty<QAction>>(92, 0x80000000 | 93, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 23),
        // property 'isContainment'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pluginName'
        QtMocHelpers::PropertyData<QString>(95, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Constraint'
        QtMocHelpers::EnumData<enum Constraint>(96, 96, QMC::EnumFlags{}).add({
            {   97, Constraint::NoConstraint },
            {   98, Constraint::FormFactorConstraint },
            {   99, Constraint::LocationConstraint },
            {  100, Constraint::ScreenConstraint },
            {  101, Constraint::ImmutableConstraint },
            {  102, Constraint::StartupCompletedConstraint },
            {  103, Constraint::UiReadyConstraint },
            {  104, Constraint::AllConstraints },
        }),
        // flag 'ConstraintHints'
        QtMocHelpers::EnumData<ConstraintHints>(105, 106, QMC::EnumIsFlag).add({
            {  107, ConstraintHint::NoHint },
            {  108, ConstraintHint::CanFillArea },
            {  109, ConstraintHint::MarginAreasSeparator },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Applet, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6Plasma6AppletE[] = {
    QMetaObject::SuperData::link<Plasma::Types::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Plasma::Applet::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma6AppletE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma6AppletE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6Plasma6AppletE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plasma6AppletE_t>.metaTypes,
    nullptr
} };

void Plasma::Applet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Applet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->immutabilityChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::ImmutabilityType>>(_a[1]))); break;
        case 1: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::ItemStatus>>(_a[1]))); break;
        case 2: _t->destroyedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->iconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->busyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->backgroundHintsChanged(); break;
        case 7: _t->userBackgroundHintsChanged(); break;
        case 8: _t->effectiveBackgroundHintsChanged(); break;
        case 9: _t->globalShortcutChanged((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 10: _t->configNeedsSaving(); break;
        case 11: _t->userConfiguringChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->contextualActionsAboutToShow(); break;
        case 13: _t->activated(); break;
        case 14: _t->secondaryActivated(); break;
        case 15: _t->appletDeleted((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 16: _t->formFactorChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::FormFactor>>(_a[1]))); break;
        case 17: _t->locationChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::Location>>(_a[1]))); break;
        case 18: _t->containmentDisplayHintsChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::ContainmentDisplayHints>>(_a[1]))); break;
        case 19: _t->configurationRequiredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->hasConfigurationInterfaceChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->constraintHintsChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Applet::ConstraintHints>>(_a[1]))); break;
        case 22: _t->containmentChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Containment*>>(_a[1]))); break;
        case 23: _t->contextualActionsChanged((*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[1]))); break;
        case 24: _t->internalActionsChanged((*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[1]))); break;
        case 25: _t->setLaunchErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->setLaunchErrorMessage(); break;
        case 27: _t->setImmutability((*reinterpret_cast<std::add_pointer_t<Types::ImmutabilityType>>(_a[1]))); break;
        case 28: _t->destroy(); break;
        case 29: _t->setStatus((*reinterpret_cast<std::add_pointer_t<Types::ItemStatus>>(_a[1]))); break;
        case 30: _t->configChanged(); break;
        case 31: _t->flushPendingConstraintsEvents(); break;
        case 32: _t->init(); break;
        case 33: _t->d->cleanUpAndDelete(); break;
        case 34: _t->d->askDestroy(); break;
        case 35: _t->d->globalShortcutChanged(); break;
        case 36: _t->d->propagateConfigChanged(); break;
        case 37: _t->d->requestConfiguration(); break;
        case 38: _t->setInternalAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[2]))); break;
        case 39: { QAction* _r = _t->internalAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAction**>(_a[0]) = std::move(_r); }  break;
        case 40: _t->removeInternalAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(Plasma::Types::ImmutabilityType )>(_a, &Applet::immutabilityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(Plasma::Types::ItemStatus )>(_a, &Applet::statusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(bool )>(_a, &Applet::destroyedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(const QString & )>(_a, &Applet::titleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(const QString & )>(_a, &Applet::iconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(bool )>(_a, &Applet::busyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)()>(_a, &Applet::backgroundHintsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)()>(_a, &Applet::userBackgroundHintsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)()>(_a, &Applet::effectiveBackgroundHintsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(const QKeySequence & )>(_a, &Applet::globalShortcutChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)()>(_a, &Applet::configNeedsSaving, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(bool )>(_a, &Applet::userConfiguringChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)()>(_a, &Applet::contextualActionsAboutToShow, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)()>(_a, &Applet::activated, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)()>(_a, &Applet::secondaryActivated, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(Plasma::Applet * )>(_a, &Applet::appletDeleted, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(Plasma::Types::FormFactor )>(_a, &Applet::formFactorChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(Plasma::Types::Location )>(_a, &Applet::locationChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(Plasma::Types::ContainmentDisplayHints )>(_a, &Applet::containmentDisplayHintsChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(bool , const QString & )>(_a, &Applet::configurationRequiredChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(bool )>(_a, &Applet::hasConfigurationInterfaceChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(Plasma::Applet::ConstraintHints )>(_a, &Applet::constraintHintsChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(Plasma::Containment * )>(_a, &Applet::containmentChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(const QList<QAction*> & )>(_a, &Applet::contextualActionsChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Applet::*)(const QList<QAction*> & )>(_a, &Applet::internalActionsChanged, 24))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->icon(); break;
        case 3: *reinterpret_cast<Plasma::Types::FormFactor*>(_v) = _t->formFactor(); break;
        case 4: *reinterpret_cast<Plasma::Types::Location*>(_v) = _t->location(); break;
        case 5: *reinterpret_cast<Plasma::Types::ItemStatus*>(_v) = _t->status(); break;
        case 6: *reinterpret_cast<Plasma::Types::ImmutabilityType*>(_v) = _t->immutability(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->immutable(); break;
        case 8: *reinterpret_cast<Plasma::Types::ContainmentDisplayHints*>(_v) = _t->containmentDisplayHints(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isBusy(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isUserConfiguring(); break;
        case 11: *reinterpret_cast<Plasma::Types::BackgroundHints*>(_v) = _t->backgroundHints(); break;
        case 12: *reinterpret_cast<Plasma::Types::BackgroundHints*>(_v) = _t->userBackgroundHints(); break;
        case 13: *reinterpret_cast<Plasma::Types::BackgroundHints*>(_v) = _t->effectiveBackgroundHints(); break;
        case 14: *reinterpret_cast<KConfigPropertyMap**>(_v) = _t->configuration(); break;
        case 15: *reinterpret_cast<QKeySequence*>(_v) = _t->globalShortcut(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->configurationRequired(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->hasConfigurationInterface(); break;
        case 18: *reinterpret_cast<Plasma::Applet::ConstraintHints*>(_v) = _t->constraintHints(); break;
        case 19: *reinterpret_cast<KPluginMetaData*>(_v) = _t->pluginMetaData(); break;
        case 20: *reinterpret_cast<Plasma::Containment**>(_v) = _t->containment(); break;
        case 21: *reinterpret_cast<QQmlListProperty<QAction>*>(_v) = _t->qmlContextualActions(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isContainment(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->pluginName(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setIcon(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setStatus(*reinterpret_cast<Plasma::Types::ItemStatus*>(_v)); break;
        case 6: _t->setImmutability(*reinterpret_cast<Plasma::Types::ImmutabilityType*>(_v)); break;
        case 9: _t->setBusy(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setBackgroundHints(*reinterpret_cast<Plasma::Types::BackgroundHints*>(_v)); break;
        case 12: _t->setUserBackgroundHints(*reinterpret_cast<Plasma::Types::BackgroundHints*>(_v)); break;
        case 15: _t->setGlobalShortcut(*reinterpret_cast<QKeySequence*>(_v)); break;
        case 16: _t->setConfigurationRequired(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setHasConfigurationInterface(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setConstraintHints(*reinterpret_cast<Plasma::Applet::ConstraintHints*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 15: _t->setGlobalShortcut(); break;
        default: break;
        }
    }
}

const QMetaObject *Plasma::Applet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma::Applet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma6AppletE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plasma::Applet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void Plasma::Applet::immutabilityChanged(Plasma::Types::ImmutabilityType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Plasma::Applet::statusChanged(Plasma::Types::ItemStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Plasma::Applet::destroyedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Plasma::Applet::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Plasma::Applet::iconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Plasma::Applet::busyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Plasma::Applet::backgroundHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Plasma::Applet::userBackgroundHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Plasma::Applet::effectiveBackgroundHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Plasma::Applet::globalShortcutChanged(const QKeySequence & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Plasma::Applet::configNeedsSaving()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Plasma::Applet::userConfiguringChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Plasma::Applet::contextualActionsAboutToShow()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Plasma::Applet::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Plasma::Applet::secondaryActivated()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Plasma::Applet::appletDeleted(Plasma::Applet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Plasma::Applet::formFactorChanged(Plasma::Types::FormFactor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Plasma::Applet::locationChanged(Plasma::Types::Location _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Plasma::Applet::containmentDisplayHintsChanged(Plasma::Types::ContainmentDisplayHints _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Plasma::Applet::configurationRequiredChanged(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void Plasma::Applet::hasConfigurationInterfaceChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Plasma::Applet::constraintHintsChanged(Plasma::Applet::ConstraintHints _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void Plasma::Applet::containmentChanged(Plasma::Containment * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void Plasma::Applet::contextualActionsChanged(const QList<QAction*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void Plasma::Applet::internalActionsChanged(const QList<QAction*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}
QT_WARNING_POP
