/* Generated by wayland-scanner 1.25.0 */

/*
 * SPDX-FileCopyrightText: 2013-2014 Pier Luigi Fiorini
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

#ifndef __has_attribute
# define __has_attribute(x) 0  /* Compatibility with non-clang compilers. */
#endif

#if (__has_attribute(visibility) || defined(__GNUC__) && __GNUC__ >= 4)
#define WL_PRIVATE __attribute__ ((visibility("hidden")))
#else
#define WL_PRIVATE
#endif

extern const struct wl_interface org_kde_plasma_surface_interface;
extern const struct wl_interface wl_output_interface;
extern const struct wl_interface wl_surface_interface;

static const struct wl_interface *plasma_shell_types[] = {
	NULL,
	NULL,
	&org_kde_plasma_surface_interface,
	&wl_surface_interface,
	&wl_output_interface,
};

static const struct wl_message org_kde_plasma_shell_requests[] = {
	{ "get_surface", "no", plasma_shell_types + 2 },
};

WL_PRIVATE const struct wl_interface org_kde_plasma_shell_interface = {
	"org_kde_plasma_shell", 8,
	1, org_kde_plasma_shell_requests,
	0, NULL,
};

static const struct wl_message org_kde_plasma_surface_requests[] = {
	{ "destroy", "", plasma_shell_types + 0 },
	{ "set_output", "o", plasma_shell_types + 4 },
	{ "set_position", "ii", plasma_shell_types + 0 },
	{ "set_role", "u", plasma_shell_types + 0 },
	{ "set_panel_behavior", "u", plasma_shell_types + 0 },
	{ "set_skip_taskbar", "2u", plasma_shell_types + 0 },
	{ "panel_auto_hide_hide", "4", plasma_shell_types + 0 },
	{ "panel_auto_hide_show", "4", plasma_shell_types + 0 },
	{ "set_panel_takes_focus", "4u", plasma_shell_types + 0 },
	{ "set_skip_switcher", "5u", plasma_shell_types + 0 },
	{ "open_under_cursor", "7", plasma_shell_types + 0 },
};

static const struct wl_message org_kde_plasma_surface_events[] = {
	{ "auto_hidden_panel_hidden", "4", plasma_shell_types + 0 },
	{ "auto_hidden_panel_shown", "4", plasma_shell_types + 0 },
};

WL_PRIVATE const struct wl_interface org_kde_plasma_surface_interface = {
	"org_kde_plasma_surface", 8,
	11, org_kde_plasma_surface_requests,
	2, org_kde_plasma_surface_events,
};

