/****************************************************************************
** Meta object code from reading C++ file 'qmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../libplasma-6.7.3/src/declarativeimports/plasmaextracomponents/qmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10QMenuProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto QMenuProxy::qt_create_metaobjectdata<qt_meta_tag_ZN10QMenuProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QMenuProxy",
        "QML.Element",
        "auto",
        "Menu",
        "DefaultProperty",
        "content",
        "statusChanged",
        "",
        "visualParentChanged",
        "transientParentChanged",
        "placementChanged",
        "preferSeamlessEdgesChanged",
        "minimumWidthChanged",
        "maximumWidthChanged",
        "triggered",
        "QMenuItem*",
        "item",
        "triggeredIndex",
        "index",
        "itemTriggered",
        "QAction*",
        "open",
        "x",
        "y",
        "openRelative",
        "close",
        "clearMenuItems",
        "addMenuItem",
        "text",
        "before",
        "addSection",
        "removeMenuItem",
        "QQmlListProperty<QMenuItem>",
        "transientParent",
        "QWindow*",
        "visualParent",
        "status",
        "Status",
        "placement",
        "PopupPlacement",
        "preferSeamlessEdges",
        "minimumWidth",
        "maximumWidth",
        "FloatingPopup",
        "TopPosedLeftAlignedPopup",
        "TopPosedRightAlignedPopup",
        "LeftPosedTopAlignedPopup",
        "LeftPosedBottomAlignedPopup",
        "BottomPosedLeftAlignedPopup",
        "BottomPosedRightAlignedPopup",
        "RightPosedTopAlignedPopup",
        "RightPosedBottomAlignedPopup",
        "Opening",
        "Open",
        "Closing",
        "Closed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(6, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visualParentChanged'
        QtMocHelpers::SignalData<void()>(8, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transientParentChanged'
        QtMocHelpers::SignalData<void()>(9, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'placementChanged'
        QtMocHelpers::SignalData<void()>(10, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preferSeamlessEdgesChanged'
        QtMocHelpers::SignalData<void()>(11, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumWidthChanged'
        QtMocHelpers::SignalData<void()>(12, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumWidthChanged'
        QtMocHelpers::SignalData<void()>(13, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggered'
        QtMocHelpers::SignalData<void(QMenuItem *)>(14, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'triggeredIndex'
        QtMocHelpers::SignalData<void(int)>(17, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'itemTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(19, 7, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 16 },
        }}),
        // Method 'open'
        QtMocHelpers::MethodData<void(int, int)>(21, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
        }}),
        // Method 'open'
        QtMocHelpers::MethodData<void(int)>(21, 7, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Method 'open'
        QtMocHelpers::MethodData<void()>(21, 7, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'openRelative'
        QtMocHelpers::MethodData<void()>(24, 7, QMC::AccessPublic, QMetaType::Void),
        // Method 'close'
        QtMocHelpers::MethodData<void()>(25, 7, QMC::AccessPublic, QMetaType::Void),
        // Method 'clearMenuItems'
        QtMocHelpers::MethodData<void()>(26, 7, QMC::AccessPublic, QMetaType::Void),
        // Method 'addMenuItem'
        QtMocHelpers::MethodData<void(const QString &)>(27, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Method 'addMenuItem'
        QtMocHelpers::MethodData<void(QMenuItem *, QMenuItem *)>(27, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 15, 29 },
        }}),
        // Method 'addMenuItem'
        QtMocHelpers::MethodData<void(QMenuItem *)>(27, 7, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'addSection'
        QtMocHelpers::MethodData<void(const QString &)>(30, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Method 'removeMenuItem'
        QtMocHelpers::MethodData<void(QMenuItem *)>(31, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'content'
        QtMocHelpers::PropertyData<QQmlListProperty<QMenuItem>>(5, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'transientParent'
        QtMocHelpers::PropertyData<QWindow*>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'visualParent'
        QtMocHelpers::PropertyData<QObject*>(35, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'placement'
        QtMocHelpers::PropertyData<enum PopupPlacement>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'preferSeamlessEdges'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'minimumWidth'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'maximumWidth'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PopupPlacement'
        QtMocHelpers::EnumData<enum PopupPlacement>(39, 39, QMC::EnumFlags{}).add({
            {   43, PopupPlacement::FloatingPopup },
            {   44, PopupPlacement::TopPosedLeftAlignedPopup },
            {   45, PopupPlacement::TopPosedRightAlignedPopup },
            {   46, PopupPlacement::LeftPosedTopAlignedPopup },
            {   47, PopupPlacement::LeftPosedBottomAlignedPopup },
            {   48, PopupPlacement::BottomPosedLeftAlignedPopup },
            {   49, PopupPlacement::BottomPosedRightAlignedPopup },
            {   50, PopupPlacement::RightPosedTopAlignedPopup },
            {   51, PopupPlacement::RightPosedBottomAlignedPopup },
        }),
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(37, 37, QMC::EnumFlags{}).add({
            {   52, Status::Opening },
            {   53, Status::Open },
            {   54, Status::Closing },
            {   55, Status::Closed },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    1,    3 },
            {    4,    5 },
    });
    return QtMocHelpers::metaObjectData<QMenuProxy, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QMenuProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QMenuProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QMenuProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10QMenuProxyE_t>.metaTypes,
    nullptr
} };

void QMenuProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QMenuProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged(); break;
        case 1: _t->visualParentChanged(); break;
        case 2: _t->transientParentChanged(); break;
        case 3: _t->placementChanged(); break;
        case 4: _t->preferSeamlessEdgesChanged(); break;
        case 5: _t->minimumWidthChanged(); break;
        case 6: _t->maximumWidthChanged(); break;
        case 7: _t->triggered((*reinterpret_cast<std::add_pointer_t<QMenuItem*>>(_a[1]))); break;
        case 8: _t->triggeredIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->itemTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 10: _t->open((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->open((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->open(); break;
        case 13: _t->openRelative(); break;
        case 14: _t->close(); break;
        case 15: _t->clearMenuItems(); break;
        case 16: _t->addMenuItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->addMenuItem((*reinterpret_cast<std::add_pointer_t<QMenuItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenuItem*>>(_a[2]))); break;
        case 18: _t->addMenuItem((*reinterpret_cast<std::add_pointer_t<QMenuItem*>>(_a[1]))); break;
        case 19: _t->addSection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->removeMenuItem((*reinterpret_cast<std::add_pointer_t<QMenuItem*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenuItem* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenuItem* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenuItem* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenuItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)()>(_a, &QMenuProxy::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)()>(_a, &QMenuProxy::visualParentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)()>(_a, &QMenuProxy::transientParentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)()>(_a, &QMenuProxy::placementChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)()>(_a, &QMenuProxy::preferSeamlessEdgesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)()>(_a, &QMenuProxy::minimumWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)()>(_a, &QMenuProxy::maximumWidthChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)(QMenuItem * )>(_a, &QMenuProxy::triggered, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMenuProxy::*)(int )>(_a, &QMenuProxy::triggeredIndex, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QMenuItem>*>(_v) = _t->content(); break;
        case 1: *reinterpret_cast<QWindow**>(_v) = _t->transientParent(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->visualParent(); break;
        case 3: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 4: *reinterpret_cast<enum PopupPlacement*>(_v) = _t->placement(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->preferSeamlessEdges(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->minimumWidth(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->maximumWidth(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setTransientParent(*reinterpret_cast<QWindow**>(_v)); break;
        case 2: _t->setVisualParent(*reinterpret_cast<QObject**>(_v)); break;
        case 4: _t->setPlacement(*reinterpret_cast<enum PopupPlacement*>(_v)); break;
        case 5: _t->setPreferSeamlessEdges(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setMinimumWidth(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setMaximumWidth(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 7: _t->resetMaximumWidth(); break;
        default: break;
        }
    }
}

const QMetaObject *QMenuProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QMenuProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QMenuProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QMenuProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void QMenuProxy::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QMenuProxy::visualParentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QMenuProxy::transientParentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QMenuProxy::placementChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QMenuProxy::preferSeamlessEdgesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QMenuProxy::minimumWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QMenuProxy::maximumWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QMenuProxy::triggered(QMenuItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QMenuProxy::triggeredIndex(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
