/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<action.h>)
#  include <action.h>
#endif
#if __has_include(<corebindingsplugin.h>)
#  include <corebindingsplugin.h>
#endif
#if __has_include(<tooltiparea.h>)
#  include <tooltiparea.h>
#endif
#if __has_include(<windowthumbnail.h>)
#  include <windowthumbnail.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_core()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<ActionExtension *>().id();
    qmlRegisterTypesAndRevisions<ActionForeign>("org.kde.plasma.core", 2);
    qmlRegisterEnum<QAction::MenuRole>("QAction::MenuRole");
    qmlRegisterEnum<QAction::Priority>("QAction::Priority");
    qmlRegisterTypesAndRevisions<ActionGroup>("org.kde.plasma.core", 2);
    qmlRegisterTypesAndRevisions<AppletForeign>("org.kde.plasma.core", 2);
    qmlRegisterEnum<Plasma::Applet::Constraint>("Plasma::Applet::Constraint");
    qmlRegisterEnum<Plasma::Applet::ConstraintHints>("Plasma::Applet::ConstraintHints");
    qmlRegisterEnum<Plasma::Applet::ConstraintHint>("Plasma::Applet::ConstraintHint");
    qmlRegisterTypesAndRevisions<AppletPopupForeign>("org.kde.plasma.core", 2);
    qmlRegisterTypesAndRevisions<ContainmentForeign>("org.kde.plasma.core", 2);
    qmlRegisterEnum<Plasma::Containment::Type>("Plasma::Containment::Type");
    qmlRegisterTypesAndRevisions<CoronaForeign>("org.kde.plasma.core", 2);
    qmlRegisterTypesAndRevisions<DialogForeign>("org.kde.plasma.core", 2);
    qmlRegisterEnum<PlasmaQuick::Dialog::WindowType>("PlasmaQuick::Dialog::WindowType");
    qmlRegisterEnum<PlasmaQuick::Dialog::BackgroundHints>("PlasmaQuick::Dialog::BackgroundHints");
    qmlRegisterTypesAndRevisions<EdgeEventForwarderForeign>("org.kde.plasma.core", 2);
    qmlRegisterTypesAndRevisions<IconForeign>("org.kde.plasma.core", 2);
    qmlRegisterEnum<QIcon::Mode>("QIcon::Mode");
    qmlRegisterEnum<QIcon::State>("QIcon::State");
    qmlRegisterEnum<QIcon::ThemeIcon>("QIcon::ThemeIcon");
    qmlRegisterTypesAndRevisions<IconGroup>("org.kde.plasma.core", 2);
    qmlRegisterTypesAndRevisions<MenuForeign>("org.kde.plasma.core", 2);
    qmlRegisterTypesAndRevisions<Plasma::WindowThumbnail>("org.kde.plasma.core", 2);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.plasma.core", 2);
    qmlRegisterTypesAndRevisions<PlasmaWindowForeign>("org.kde.plasma.core", 2);
    qmlRegisterEnum<PlasmaQuick::PlasmaWindow::BackgroundHints>("PlasmaQuick::PlasmaWindow::BackgroundHints");
    qmlRegisterTypesAndRevisions<PopupPlasmaWindowForeign>("org.kde.plasma.core", 2);
    qmlRegisterEnum<PlasmaQuick::PopupPlasmaWindow::RemoveBorders>("PlasmaQuick::PopupPlasmaWindow::RemoveBorders");
    qmlRegisterEnum<PlasmaQuick::PopupPlasmaWindow::RemoveBorder>("PlasmaQuick::PopupPlasmaWindow::RemoveBorder");
    qmlRegisterTypesAndRevisions<PropertyMapForeign>("org.kde.plasma.core", 2);
    QMetaType::fromType<QActionGroup *>().id();
    qmlRegisterEnum<QActionGroup::ExclusionPolicy>("QActionGroup::ExclusionPolicy");
    QMetaType::fromType<QWidget *>().id();
    qmlRegisterTypesAndRevisions<ToolTipArea>("org.kde.plasma.core", 2);
    qmlRegisterTypesAndRevisions<TypesForeign>("org.kde.plasma.core", 2);
    qmlRegisterEnum<Plasma::Types::FormFactor>("Plasma::Types::FormFactor");
    qmlRegisterEnum<Plasma::Types::ContainmentDisplayHint>("Plasma::Types::ContainmentDisplayHint");
    qmlRegisterEnum<Plasma::Types::ContainmentDisplayHints>("Plasma::Types::ContainmentDisplayHints");
    qmlRegisterEnum<Plasma::Types::ContainmentDisplayHint>("Plasma::Types::ContainmentDisplayHint");
    qmlRegisterEnum<Plasma::Types::Location>("Plasma::Types::Location");
    qmlRegisterEnum<Plasma::Types::ImmutabilityType>("Plasma::Types::ImmutabilityType");
    qmlRegisterEnum<Plasma::Types::ItemStatus>("Plasma::Types::ItemStatus");
    qmlRegisterEnum<Plasma::Types::BackgroundHints>("Plasma::Types::BackgroundHints");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.core", 2, 0);
}

static const QQmlModuleRegistration orgkdeplasmacoreRegistration("org.kde.plasma.core", qml_register_types_org_kde_plasma_core);
