/****************************************************************************
** Meta object code from reading C++ file 'sharedqmlengine.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.7.3/src/plasmaquick/sharedqmlengine.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sharedqmlengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlasmaQuick15SharedQmlEngineE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaQuick::SharedQmlEngine::qt_create_metaobjectdata<qt_meta_tag_ZN11PlasmaQuick15SharedQmlEngineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaQuick::SharedQmlEngine",
        "finished",
        "",
        "statusChanged",
        "QQmlComponent::Status",
        "completeInitialization",
        "QVariantHash",
        "initialProperties",
        "scheduleExecutionEnd",
        "source",
        "QUrl",
        "translationDomain",
        "initializationDelayed",
        "rootObject",
        "status"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(QQmlComponent::Status)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'completeInitialization'
        QtMocHelpers::SlotData<void(const QVariantHash &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'completeInitialization'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'scheduleExecutionEnd'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'translationDomain'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'initializationDelayed'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'rootObject'
        QtMocHelpers::PropertyData<QObject*>(13, QMetaType::QObjectStar, QMC::DefaultPropertyFlags),
        // property 'status'
        QtMocHelpers::PropertyData<QQmlComponent::Status>(14, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SharedQmlEngine, qt_meta_tag_ZN11PlasmaQuick15SharedQmlEngineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11PlasmaQuick15SharedQmlEngineE[] = {
    QMetaObject::SuperData::link<QQmlComponent::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PlasmaQuick::SharedQmlEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15SharedQmlEngineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15SharedQmlEngineE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11PlasmaQuick15SharedQmlEngineE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlasmaQuick15SharedQmlEngineE_t>.metaTypes,
    nullptr
} };

void PlasmaQuick::SharedQmlEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SharedQmlEngine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished(); break;
        case 1: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent::Status>>(_a[1]))); break;
        case 2: _t->completeInitialization((*reinterpret_cast<std::add_pointer_t<QVariantHash>>(_a[1]))); break;
        case 3: _t->completeInitialization(); break;
        case 4: _t->d->scheduleExecutionEnd(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SharedQmlEngine::*)()>(_a, &SharedQmlEngine::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SharedQmlEngine::*)(QQmlComponent::Status )>(_a, &SharedQmlEngine::statusChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->translationDomain(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isInitializationDelayed(); break;
        case 3: *reinterpret_cast<QObject**>(_v) = _t->rootObject(); break;
        case 4: *reinterpret_cast<QQmlComponent::Status*>(_v) = _t->status(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 1: _t->setTranslationDomain(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setInitializationDelayed(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaQuick::SharedQmlEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaQuick::SharedQmlEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15SharedQmlEngineE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PlasmaQuick::SharedQmlEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void PlasmaQuick::SharedQmlEngine::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlasmaQuick::SharedQmlEngine::statusChanged(QQmlComponent::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
