/****************************************************************************
** Meta object code from reading C++ file 'corebindingsplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../libplasma-6.7.3/src/declarativeimports/core/corebindingsplugin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corebindingsplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12TypesForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto TypesForeign::qt_create_metaobjectdata<qt_meta_tag_ZN12TypesForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TypesForeign",
        "QML.Element",
        "Types",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "QML.Foreign",
        "Plasma::Types"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<TypesForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TypesForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TypesForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TypesForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12TypesForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18PropertyMapForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto PropertyMapForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18PropertyMapForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PropertyMapForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QQmlPropertyMap"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PropertyMapForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PropertyMapForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PropertyMapForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PropertyMapForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PropertyMapForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19PlasmaWindowForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaWindowForeign::qt_create_metaobjectdata<qt_meta_tag_ZN19PlasmaWindowForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaWindowForeign",
        "QML.Element",
        "Window",
        "QML.Foreign",
        "PlasmaQuick::PlasmaWindow"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PlasmaWindowForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PlasmaWindowForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PlasmaWindowForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PlasmaWindowForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19PlasmaWindowForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18AppletPopupForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto AppletPopupForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18AppletPopupForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppletPopupForeign",
        "QML.Element",
        "AppletPopup",
        "QML.Foreign",
        "PlasmaQuick::AppletPopup"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AppletPopupForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AppletPopupForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AppletPopupForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AppletPopupForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18AppletPopupForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN24PopupPlasmaWindowForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto PopupPlasmaWindowForeign::qt_create_metaobjectdata<qt_meta_tag_ZN24PopupPlasmaWindowForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PopupPlasmaWindowForeign",
        "QML.Element",
        "PopupPlasmaWindow",
        "QML.Foreign",
        "PlasmaQuick::PopupPlasmaWindow"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PopupPlasmaWindowForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PopupPlasmaWindowForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24PopupPlasmaWindowForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24PopupPlasmaWindowForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24PopupPlasmaWindowForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN13DialogForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto DialogForeign::qt_create_metaobjectdata<qt_meta_tag_ZN13DialogForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DialogForeign",
        "QML.Element",
        "Dialog",
        "QML.Foreign",
        "PlasmaQuick::Dialog"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DialogForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DialogForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DialogForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DialogForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DialogForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18ContainmentForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto ContainmentForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18ContainmentForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ContainmentForeign",
        "QML.Element",
        "Containment",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "QML.Foreign",
        "Plasma::Containment"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<ContainmentForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ContainmentForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ContainmentForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ContainmentForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ContainmentForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN13CoronaForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CoronaForeign::qt_create_metaobjectdata<qt_meta_tag_ZN13CoronaForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CoronaForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "Plasma::Corona"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CoronaForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CoronaForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CoronaForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CoronaForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13CoronaForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN13AppletForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto AppletForeign::qt_create_metaobjectdata<qt_meta_tag_ZN13AppletForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppletForeign",
        "QML.Element",
        "Applet",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "QML.Foreign",
        "Plasma::Applet"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<AppletForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AppletForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AppletForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AppletForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13AppletForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN13ActionForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto ActionForeign::qt_create_metaobjectdata<qt_meta_tag_ZN13ActionForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActionForeign",
        "QML.Element",
        "Action",
        "QML.Foreign",
        "QAction",
        "QML.Extended",
        "ActionExtension"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ActionForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ActionForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ActionForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ActionForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ActionForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN11MenuForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto MenuForeign::qt_create_metaobjectdata<qt_meta_tag_ZN11MenuForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MenuForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QMenu"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MenuForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MenuForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MenuForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MenuForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MenuForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN11IconForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto IconForeign::qt_create_metaobjectdata<qt_meta_tag_ZN11IconForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IconForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QIcon"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<IconForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject IconForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11IconForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11IconForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11IconForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN25EdgeEventForwarderForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto EdgeEventForwarderForeign::qt_create_metaobjectdata<qt_meta_tag_ZN25EdgeEventForwarderForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EdgeEventForwarderForeign",
        "QML.Element",
        "EdgeEventForwarder",
        "QML.Foreign",
        "PlasmaQuick::EdgeEventForwarder"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<EdgeEventForwarderForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EdgeEventForwarderForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25EdgeEventForwarderForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25EdgeEventForwarderForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25EdgeEventForwarderForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18CoreBindingsPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto CoreBindingsPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN18CoreBindingsPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CoreBindingsPlugin"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CoreBindingsPlugin, qt_meta_tag_ZN18CoreBindingsPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CoreBindingsPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QQmlExtensionPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CoreBindingsPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CoreBindingsPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CoreBindingsPluginE_t>.metaTypes,
    nullptr
} };

void CoreBindingsPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CoreBindingsPlugin *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CoreBindingsPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreBindingsPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CoreBindingsPluginE_t>.strings))
        return static_cast<void*>(this);
    return QQmlExtensionPlugin::qt_metacast(_clname);
}

int CoreBindingsPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQmlExtensionPlugin::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_CoreBindingsPlugin[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x28,  'o',  'r',  'g',  '.',  'q', 
    't',  '-',  'p',  'r',  'o',  'j',  'e',  'c', 
    't',  '.',  'Q',  't',  '.',  'Q',  'Q',  'm', 
    'l',  'E',  'x',  't',  'e',  'n',  's',  'i', 
    'o',  'n',  'I',  'n',  't',  'e',  'r',  'f', 
    'a',  'c',  'e', 
    // "className"
    0x03,  0x72,  'C',  'o',  'r',  'e',  'B',  'i', 
    'n',  'd',  'i',  'n',  'g',  's',  'P',  'l', 
    'u',  'g',  'i',  'n', 
    // command-line "uri"
    0x63,  'u',  'r',  'i',  0x81,  0x73,  'o',  'r', 
    'g',  '.',  'k',  'd',  'e',  '.',  'p',  'l', 
    'a',  's',  'm',  'a',  '.',  'c',  'o',  'r', 
    'e', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(CoreBindingsPlugin, CoreBindingsPlugin, qt_pluginMetaDataV2_CoreBindingsPlugin)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_CoreBindingsPlugin[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x28,  'o',  'r',  'g',  '.',  'q', 
    't',  '-',  'p',  'r',  'o',  'j',  'e',  'c', 
    't',  '.',  'Q',  't',  '.',  'Q',  'Q',  'm', 
    'l',  'E',  'x',  't',  'e',  'n',  's',  'i', 
    'o',  'n',  'I',  'n',  't',  'e',  'r',  'f', 
    'a',  'c',  'e', 
    // "className"
    0x03,  0x72,  'C',  'o',  'r',  'e',  'B',  'i', 
    'n',  'd',  'i',  'n',  'g',  's',  'P',  'l', 
    'u',  'g',  'i',  'n', 
    // command-line "uri"
    0x63,  'u',  'r',  'i',  0x81,  0x73,  'o',  'r', 
    'g',  '.',  'k',  'd',  'e',  '.',  'p',  'l', 
    'a',  's',  'm',  'a',  '.',  'c',  'o',  'r', 
    'e', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(CoreBindingsPlugin, CoreBindingsPlugin)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
