/****************************************************************************
** Meta object code from reading C++ file 'plasma.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.7.3/src/plasma/plasma.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasma.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Plasma5TypesE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma::Types::qt_create_metaobjectdata<qt_meta_tag_ZN6Plasma5TypesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma::Types",
        "FormFactor",
        "Planar",
        "MediaCenter",
        "Horizontal",
        "Vertical",
        "Application",
        "ContainmentDisplayHint",
        "NoContainmentDisplayHint",
        "ContainmentDrawsPlasmoidHeading",
        "ContainmentForcesSquarePlasmoids",
        "ContainmentPrefersOpaqueBackground",
        "ContainmentPrefersFloatingApplets",
        "ContainmentDisplayHints",
        "Location",
        "Floating",
        "Desktop",
        "FullScreen",
        "TopEdge",
        "BottomEdge",
        "LeftEdge",
        "RightEdge",
        "ImmutabilityType",
        "Mutable",
        "UserImmutable",
        "SystemImmutable",
        "ItemStatus",
        "UnknownStatus",
        "PassiveStatus",
        "ActiveStatus",
        "NeedsAttentionStatus",
        "RequiresAttentionStatus",
        "AcceptingInputStatus",
        "HiddenStatus",
        "BackgroundHints",
        "NoBackground",
        "StandardBackground",
        "TranslucentBackground",
        "ShadowBackground",
        "ConfigurableBackground",
        "DefaultBackground"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FormFactor'
        QtMocHelpers::EnumData<enum FormFactor>(1, 1, QMC::EnumFlags{}).add({
            {    2, FormFactor::Planar },
            {    3, FormFactor::MediaCenter },
            {    4, FormFactor::Horizontal },
            {    5, FormFactor::Vertical },
            {    6, FormFactor::Application },
        }),
        // enum 'ContainmentDisplayHint'
        QtMocHelpers::EnumData<enum ContainmentDisplayHint>(7, 7, QMC::EnumFlags{}).add({
            {    8, ContainmentDisplayHint::NoContainmentDisplayHint },
            {    9, ContainmentDisplayHint::ContainmentDrawsPlasmoidHeading },
            {   10, ContainmentDisplayHint::ContainmentForcesSquarePlasmoids },
            {   11, ContainmentDisplayHint::ContainmentPrefersOpaqueBackground },
            {   12, ContainmentDisplayHint::ContainmentPrefersFloatingApplets },
        }),
        // flag 'ContainmentDisplayHints'
        QtMocHelpers::EnumData<ContainmentDisplayHints>(13, 7, QMC::EnumIsFlag).add({
            {    8, ContainmentDisplayHint::NoContainmentDisplayHint },
            {    9, ContainmentDisplayHint::ContainmentDrawsPlasmoidHeading },
            {   10, ContainmentDisplayHint::ContainmentForcesSquarePlasmoids },
            {   11, ContainmentDisplayHint::ContainmentPrefersOpaqueBackground },
            {   12, ContainmentDisplayHint::ContainmentPrefersFloatingApplets },
        }),
        // enum 'Location'
        QtMocHelpers::EnumData<enum Location>(14, 14, QMC::EnumFlags{}).add({
            {   15, Location::Floating },
            {   16, Location::Desktop },
            {   17, Location::FullScreen },
            {   18, Location::TopEdge },
            {   19, Location::BottomEdge },
            {   20, Location::LeftEdge },
            {   21, Location::RightEdge },
        }),
        // enum 'ImmutabilityType'
        QtMocHelpers::EnumData<enum ImmutabilityType>(22, 22, QMC::EnumFlags{}).add({
            {   23, ImmutabilityType::Mutable },
            {   24, ImmutabilityType::UserImmutable },
            {   25, ImmutabilityType::SystemImmutable },
        }),
        // enum 'ItemStatus'
        QtMocHelpers::EnumData<enum ItemStatus>(26, 26, QMC::EnumFlags{}).add({
            {   27, ItemStatus::UnknownStatus },
            {   28, ItemStatus::PassiveStatus },
            {   29, ItemStatus::ActiveStatus },
            {   30, ItemStatus::NeedsAttentionStatus },
            {   31, ItemStatus::RequiresAttentionStatus },
            {   32, ItemStatus::AcceptingInputStatus },
            {   33, ItemStatus::HiddenStatus },
        }),
        // enum 'BackgroundHints'
        QtMocHelpers::EnumData<enum BackgroundHints>(34, 34, QMC::EnumFlags{}).add({
            {   35, BackgroundHints::NoBackground },
            {   36, BackgroundHints::StandardBackground },
            {   37, BackgroundHints::TranslucentBackground },
            {   38, BackgroundHints::ShadowBackground },
            {   39, BackgroundHints::ConfigurableBackground },
            {   40, BackgroundHints::DefaultBackground },
        }),
    };
    return QtMocHelpers::metaObjectData<Types, qt_meta_tag_ZN6Plasma5TypesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plasma::Types::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma5TypesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma5TypesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plasma5TypesE_t>.metaTypes,
    nullptr
} };

void Plasma::Types::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Types *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Plasma::Types::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma::Types::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma5TypesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plasma::Types::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
