// This file was generated by qtwaylandscanner
// source file is ext-background-effect-v1.xml

#ifndef QT_WAYLAND_EXT_BACKGROUND_EFFECT_V1
#define QT_WAYLAND_EXT_BACKGROUND_EFFECT_V1

#include "wayland-ext-background-effect-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  ext_background_effect_manager_v1
    {
    public:
        ext_background_effect_manager_v1(struct ::wl_registry *registry, uint32_t id, int version);
        ext_background_effect_manager_v1(struct ::ext_background_effect_manager_v1 *object);
        ext_background_effect_manager_v1();

        virtual ~ext_background_effect_manager_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::ext_background_effect_manager_v1 *object);

        struct ::ext_background_effect_manager_v1 *object() { return m_ext_background_effect_manager_v1; }
        const struct ::ext_background_effect_manager_v1 *object() const { return m_ext_background_effect_manager_v1; }
        static ext_background_effect_manager_v1 *fromObject(struct ::ext_background_effect_manager_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_background_effect_exists = 0, // the surface already has a background effect object
        };

        enum capability {
            capability_blur = 1, // the compositor supports applying blur
        };

        void destroy();
        struct ::ext_background_effect_surface_v1 *get_background_effect(struct ::wl_surface *surface);

    protected:
        virtual void ext_background_effect_manager_v1_capabilities(uint32_t flags);

    private:
        void init_listener();
        static const struct ext_background_effect_manager_v1_listener m_ext_background_effect_manager_v1_listener;
        static void handle_capabilities(
            void *data,
            struct ::ext_background_effect_manager_v1 *object,
            uint32_t flags);
        struct ::ext_background_effect_manager_v1 *m_ext_background_effect_manager_v1;
    };

    class  ext_background_effect_surface_v1
    {
    public:
        ext_background_effect_surface_v1(struct ::wl_registry *registry, uint32_t id, int version);
        ext_background_effect_surface_v1(struct ::ext_background_effect_surface_v1 *object);
        ext_background_effect_surface_v1();

        virtual ~ext_background_effect_surface_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::ext_background_effect_surface_v1 *object);

        struct ::ext_background_effect_surface_v1 *object() { return m_ext_background_effect_surface_v1; }
        const struct ::ext_background_effect_surface_v1 *object() const { return m_ext_background_effect_surface_v1; }
        static ext_background_effect_surface_v1 *fromObject(struct ::ext_background_effect_surface_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_surface_destroyed = 0, // the associated surface has been destroyed
        };

        void destroy();
        void set_blur_region(struct ::wl_region *region);

    private:
        struct ::ext_background_effect_surface_v1 *m_ext_background_effect_surface_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
