/****************************************************************************
** Meta object code from reading C++ file 'containment.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.7.3/src/plasma/containment.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'containment.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Plasma11ContainmentE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma::Containment::qt_create_metaobjectdata<qt_meta_tag_ZN6Plasma11ContainmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma::Containment",
        "appletAdded",
        "",
        "Plasma::Applet*",
        "applet",
        "QRectF",
        "geometryHint",
        "appletAboutToBeAdded",
        "appletRemoved",
        "appletAboutToBeRemoved",
        "appletCreated",
        "appletsChanged",
        "activityChanged",
        "activity",
        "activityNameChanged",
        "name",
        "showAddWidgetsInterface",
        "QPointF",
        "pos",
        "screenChanged",
        "newScreen",
        "configureRequested",
        "appletAlternativesRequested",
        "wallpaperPluginChanged",
        "locationChanged",
        "Plasma::Types::Location",
        "location",
        "formFactorChanged",
        "Plasma::Types::FormFactor",
        "formFactor",
        "uiReadyChanged",
        "uiReady",
        "containmentTypeChanged",
        "availableRelativeScreenRectChanged",
        "rect",
        "availableRelativeScreenRegionChanged",
        "QList<QRectF>",
        "region",
        "screenGeometryChanged",
        "wallpaperGraphicsObjectChanged",
        "setLocation",
        "setFormFactor",
        "setContainmentDisplayHints",
        "Plasma::Types::ContainmentDisplayHints",
        "hints",
        "reactToScreenChange",
        "appletDeleted",
        "triggerShowAddWidgets",
        "checkStatus",
        "Plasma::Types::ItemStatus",
        "addApplet",
        "Applet*",
        "containmentDisplayHintsChanged",
        "applets",
        "QList<Plasma::Applet*>",
        "corona",
        "Plasma::Corona*",
        "containmentType",
        "Plasma::Containment::Type",
        "activityName",
        "containmentDisplayHints",
        "wallpaperPlugin",
        "wallpaperGraphicsObject",
        "isUiReady",
        "screen",
        "availableScreenRect",
        "availableScreenRegion",
        "screenGeometry",
        "Type",
        "NoContainment",
        "Desktop",
        "Panel",
        "Custom",
        "CustomPanel",
        "CustomEmbedded"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'appletAdded'
        QtMocHelpers::SignalData<void(Plasma::Applet *, const QRectF &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'appletAboutToBeAdded'
        QtMocHelpers::SignalData<void(Plasma::Applet *, const QRectF &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'appletRemoved'
        QtMocHelpers::SignalData<void(Plasma::Applet *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'appletAboutToBeRemoved'
        QtMocHelpers::SignalData<void(Plasma::Applet *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'appletCreated'
        QtMocHelpers::SignalData<void(Plasma::Applet *, const QRectF &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'appletsChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'activityNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'showAddWidgetsInterface'
        QtMocHelpers::SignalData<void(const QPointF &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'screenChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'configureRequested'
        QtMocHelpers::SignalData<void(Plasma::Applet *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'appletAlternativesRequested'
        QtMocHelpers::SignalData<void(Plasma::Applet *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'wallpaperPluginChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::Location)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Signal 'formFactorChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::FormFactor)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'uiReadyChanged'
        QtMocHelpers::SignalData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'containmentTypeChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableRelativeScreenRectChanged'
        QtMocHelpers::SignalData<void(const QRectF &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 34 },
        }}),
        // Signal 'availableRelativeScreenRegionChanged'
        QtMocHelpers::SignalData<void(const QList<QRectF> &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void(const QRectF &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 34 },
        }}),
        // Signal 'wallpaperGraphicsObjectChanged'
        QtMocHelpers::SignalData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLocation'
        QtMocHelpers::SlotData<void(Plasma::Types::Location)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'setFormFactor'
        QtMocHelpers::SlotData<void(Plasma::Types::FormFactor)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'setContainmentDisplayHints'
        QtMocHelpers::SlotData<void(Plasma::Types::ContainmentDisplayHints)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Slot 'reactToScreenChange'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appletDeleted'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'triggerShowAddWidgets'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkStatus'
        QtMocHelpers::SlotData<void(Plasma::Types::ItemStatus)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 49, 2 },
        }}),
        // Method 'addApplet'
        QtMocHelpers::MethodData<void(Applet *, const QRectF &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Method 'addApplet'
        QtMocHelpers::MethodData<void(Applet *)>(50, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 51, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'applets'
        QtMocHelpers::PropertyData<QList<Plasma::Applet*>>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'corona'
        QtMocHelpers::PropertyData<Plasma::Corona*>(55, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'containmentType'
        QtMocHelpers::PropertyData<Plasma::Containment::Type>(57, 0x80000000 | 58, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 16),
        // property 'activity'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'activityName'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'containmentDisplayHints'
        QtMocHelpers::PropertyData<Plasma::Types::ContainmentDisplayHints>(60, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 52),
        // property 'wallpaperPlugin'
        QtMocHelpers::PropertyData<QString>(61, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'wallpaperGraphicsObject'
        QtMocHelpers::PropertyData<QObject*>(62, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isUiReady'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags, 15),
        // property 'screen'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'availableScreenRect'
        QtMocHelpers::PropertyData<QRectF>(65, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 17),
        // property 'availableScreenRegion'
        QtMocHelpers::PropertyData<QList<QRectF>>(66, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 18),
        // property 'screenGeometry'
        QtMocHelpers::PropertyData<QRectF>(67, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 19),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(68, 68, QMC::EnumFlags{}).add({
            {   69, Type::NoContainment },
            {   70, Type::Desktop },
            {   71, Type::Panel },
            {   72, Type::Custom },
            {   73, Type::CustomPanel },
            {   74, Type::CustomEmbedded },
        }),
    };
    return QtMocHelpers::metaObjectData<Containment, qt_meta_tag_ZN6Plasma11ContainmentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6Plasma11ContainmentE[] = {
    QMetaObject::SuperData::link<Plasma::Types::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Plasma::Containment::staticMetaObject = { {
    QMetaObject::SuperData::link<Applet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma11ContainmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma11ContainmentE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6Plasma11ContainmentE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plasma11ContainmentE_t>.metaTypes,
    nullptr
} };

void Plasma::Containment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Containment *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->appletAdded((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2]))); break;
        case 1: _t->appletAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2]))); break;
        case 2: _t->appletRemoved((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 3: _t->appletAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 4: _t->appletCreated((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2]))); break;
        case 5: _t->appletsChanged(); break;
        case 6: _t->activityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->activityNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->showAddWidgetsInterface((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 9: _t->screenChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->configureRequested((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 11: _t->appletAlternativesRequested((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 12: _t->wallpaperPluginChanged(); break;
        case 13: _t->locationChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::Location>>(_a[1]))); break;
        case 14: _t->formFactorChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::FormFactor>>(_a[1]))); break;
        case 15: _t->uiReadyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->containmentTypeChanged(); break;
        case 17: _t->availableRelativeScreenRectChanged((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 18: _t->availableRelativeScreenRegionChanged((*reinterpret_cast<std::add_pointer_t<QList<QRectF>>>(_a[1]))); break;
        case 19: _t->screenGeometryChanged((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 20: _t->wallpaperGraphicsObjectChanged(); break;
        case 21: _t->setLocation((*reinterpret_cast<std::add_pointer_t<Plasma::Types::Location>>(_a[1]))); break;
        case 22: _t->setFormFactor((*reinterpret_cast<std::add_pointer_t<Plasma::Types::FormFactor>>(_a[1]))); break;
        case 23: _t->setContainmentDisplayHints((*reinterpret_cast<std::add_pointer_t<Plasma::Types::ContainmentDisplayHints>>(_a[1]))); break;
        case 24: _t->reactToScreenChange(); break;
        case 25: _t->d->appletDeleted((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 26: _t->d->triggerShowAddWidgets(); break;
        case 27: _t->d->checkStatus((*reinterpret_cast<std::add_pointer_t<Plasma::Types::ItemStatus>>(_a[1]))); break;
        case 28: _t->addApplet((*reinterpret_cast<std::add_pointer_t<Applet*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2]))); break;
        case 29: _t->addApplet((*reinterpret_cast<std::add_pointer_t<Applet*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Applet* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Applet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Applet * , const QRectF & )>(_a, &Containment::appletAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Applet * , const QRectF & )>(_a, &Containment::appletAboutToBeAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Applet * )>(_a, &Containment::appletRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Applet * )>(_a, &Containment::appletAboutToBeRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Applet * , const QRectF & )>(_a, &Containment::appletCreated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)()>(_a, &Containment::appletsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(const QString & )>(_a, &Containment::activityChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(const QString & )>(_a, &Containment::activityNameChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(const QPointF & )>(_a, &Containment::showAddWidgetsInterface, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(int )>(_a, &Containment::screenChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Applet * )>(_a, &Containment::configureRequested, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Applet * )>(_a, &Containment::appletAlternativesRequested, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)()>(_a, &Containment::wallpaperPluginChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Types::Location )>(_a, &Containment::locationChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(Plasma::Types::FormFactor )>(_a, &Containment::formFactorChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(bool )>(_a, &Containment::uiReadyChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)()>(_a, &Containment::containmentTypeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(const QRectF & )>(_a, &Containment::availableRelativeScreenRectChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(const QList<QRectF> & )>(_a, &Containment::availableRelativeScreenRegionChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)(const QRectF & )>(_a, &Containment::screenGeometryChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Containment::*)()>(_a, &Containment::wallpaperGraphicsObjectChanged, 20))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<Plasma::Applet*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<Plasma::Applet*>*>(_v) = _t->applets(); break;
        case 1: *reinterpret_cast<Plasma::Corona**>(_v) = _t->corona(); break;
        case 2: *reinterpret_cast<Plasma::Containment::Type*>(_v) = _t->containmentType(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->activity(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->activityName(); break;
        case 5: *reinterpret_cast<Plasma::Types::ContainmentDisplayHints*>(_v) = _t->containmentDisplayHints(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->wallpaperPlugin(); break;
        case 7: *reinterpret_cast<QObject**>(_v) = _t->wallpaperGraphicsObject(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isUiReady(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->screen(); break;
        case 10: *reinterpret_cast<QRectF*>(_v) = _t->availableRelativeScreenRect(); break;
        case 11: *reinterpret_cast<QList<QRectF>*>(_v) = _t->availableRelativeScreenRegion(); break;
        case 12: *reinterpret_cast<QRectF*>(_v) = _t->screenGeometry(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setContainmentDisplayHints(*reinterpret_cast<Plasma::Types::ContainmentDisplayHints*>(_v)); break;
        case 6: _t->setWallpaperPlugin(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setWallpaperGraphicsObject(*reinterpret_cast<QObject**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Plasma::Containment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma::Containment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma11ContainmentE_t>.strings))
        return static_cast<void*>(this);
    return Applet::qt_metacast(_clname);
}

int Plasma::Containment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Applet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Plasma::Containment::appletAdded(Plasma::Applet * _t1, const QRectF & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Plasma::Containment::appletAboutToBeAdded(Plasma::Applet * _t1, const QRectF & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Plasma::Containment::appletRemoved(Plasma::Applet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Plasma::Containment::appletAboutToBeRemoved(Plasma::Applet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Plasma::Containment::appletCreated(Plasma::Applet * _t1, const QRectF & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Plasma::Containment::appletsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Plasma::Containment::activityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Plasma::Containment::activityNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Plasma::Containment::showAddWidgetsInterface(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Plasma::Containment::screenChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Plasma::Containment::configureRequested(Plasma::Applet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Plasma::Containment::appletAlternativesRequested(Plasma::Applet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Plasma::Containment::wallpaperPluginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Plasma::Containment::locationChanged(Plasma::Types::Location _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Plasma::Containment::formFactorChanged(Plasma::Types::FormFactor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Plasma::Containment::uiReadyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Plasma::Containment::containmentTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Plasma::Containment::availableRelativeScreenRectChanged(const QRectF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Plasma::Containment::availableRelativeScreenRegionChanged(const QList<QRectF> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Plasma::Containment::screenGeometryChanged(const QRectF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void Plasma::Containment::wallpaperGraphicsObjectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
namespace CheckNotifySignalValidity_ZN6Plasma11ContainmentE {
template<typename T> using has_nullary_containmentDisplayHintsChanged = decltype(std::declval<T>().containmentDisplayHintsChanged());
template<typename T> using has_unary_containmentDisplayHintsChanged = decltype(std::declval<T>().containmentDisplayHintsChanged(std::declval<Plasma::Types::ContainmentDisplayHints>()));
static_assert(qxp::is_detected_v<has_nullary_containmentDisplayHintsChanged, Plasma::Containment> || qxp::is_detected_v<has_unary_containmentDisplayHintsChanged, Plasma::Containment>,
              "NOTIFY signal containmentDisplayHintsChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
