/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<plasmoidattached_p.h>)
#  include <plasmoidattached_p.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_plasmoid()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ContainmentItemForeign>("org.kde.plasma.plasmoid", 2);
    qmlRegisterTypesAndRevisions<CoronaForeign>("org.kde.plasma.plasmoid", 2);
    QMetaType::fromType<Plasma::Containment *>().id();
    qmlRegisterEnum<Plasma::Containment::Type>("Plasma::Containment::Type");
    QMetaType::fromType<PlasmaQuick::AppletQuickItem *>().id();
    qmlRegisterTypesAndRevisions<PlasmaQuick::ContainmentAttached>("org.kde.plasma.plasmoid", 2);
    qmlRegisterTypesAndRevisions<PlasmaQuick::PlasmoidAttached>("org.kde.plasma.plasmoid", 2);
    qmlRegisterEnum<PlasmaQuick::PlasmoidAttached::ActionPriority>("PlasmaQuick::PlasmoidAttached::ActionPriority");
    qmlRegisterTypesAndRevisions<PlasmoidItemForeign>("org.kde.plasma.plasmoid", 2);
    qmlRegisterTypesAndRevisions<WallpaperItemForeign>("org.kde.plasma.plasmoid", 2);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.plasmoid", 2, 0);
}

static const QQmlModuleRegistration orgkdeplasmaplasmoidRegistration("org.kde.plasma.plasmoid", qml_register_types_org_kde_plasma_plasmoid);
