/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<qmenu.h>)
#  include <qmenu.h>
#endif
#if __has_include(<qmenuitem.h>)
#  include <qmenuitem.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_extras()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QMenuItem>("org.kde.plasma.extras", 2);
    qmlRegisterTypesAndRevisions<QMenuProxy>("org.kde.plasma.extras", 2);
    qmlRegisterEnum<QMenuProxy::PopupPlacement>("QMenuProxy::PopupPlacement");
    qmlRegisterEnum<QMenuProxy::Status>("QMenuProxy::Status");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.extras", 2, 0);
}

static const QQmlModuleRegistration orgkdeplasmaextrasRegistration("org.kde.plasma.extras", qml_register_types_org_kde_plasma_extras);
