/****************************************************************************
** Meta object code from reading C++ file 'containmentview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.7.3/src/plasmaquick/containmentview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'containmentview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlasmaQuick15ContainmentViewE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaQuick::ContainmentView::qt_create_metaobjectdata<qt_meta_tag_ZN11PlasmaQuick15ContainmentViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaQuick::ContainmentView",
        "locationChanged",
        "",
        "Plasma::Types::Location",
        "location",
        "formFactorChanged",
        "Plasma::Types::FormFactor",
        "formFactor",
        "containmentChanged",
        "screenGeometryChanged",
        "showConfigurationInterface",
        "Plasma::Applet*",
        "applet",
        "updateDestroyed",
        "screenGeometry",
        "QRectF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::Location)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'formFactorChanged'
        QtMocHelpers::SignalData<void(Plasma::Types::FormFactor)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'containmentChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showConfigurationInterface'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'updateDestroyed'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'location'
        QtMocHelpers::PropertyData<Plasma::Types::Location>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'formFactor'
        QtMocHelpers::PropertyData<Plasma::Types::FormFactor>(7, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'screenGeometry'
        QtMocHelpers::PropertyData<QRectF>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ContainmentView, qt_meta_tag_ZN11PlasmaQuick15ContainmentViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11PlasmaQuick15ContainmentViewE[] = {
    QMetaObject::SuperData::link<Plasma::Types::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PlasmaQuick::ContainmentView::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmaQuick::QuickViewSharedEngine::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15ContainmentViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15ContainmentViewE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11PlasmaQuick15ContainmentViewE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlasmaQuick15ContainmentViewE_t>.metaTypes,
    nullptr
} };

void PlasmaQuick::ContainmentView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ContainmentView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->locationChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::Location>>(_a[1]))); break;
        case 1: _t->formFactorChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::FormFactor>>(_a[1]))); break;
        case 2: _t->containmentChanged(); break;
        case 3: _t->screenGeometryChanged(); break;
        case 4: _t->showConfigurationInterface((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 5: _t->d->updateDestroyed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ContainmentView::*)(Plasma::Types::Location )>(_a, &ContainmentView::locationChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentView::*)(Plasma::Types::FormFactor )>(_a, &ContainmentView::formFactorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentView::*)()>(_a, &ContainmentView::containmentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentView::*)()>(_a, &ContainmentView::screenGeometryChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Plasma::Types::Location*>(_v) = _t->location(); break;
        case 1: *reinterpret_cast<Plasma::Types::FormFactor*>(_v) = _t->formFactor(); break;
        case 2: *reinterpret_cast<QRectF*>(_v) = _t->screenGeometry(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLocation(*reinterpret_cast<Plasma::Types::Location*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaQuick::ContainmentView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaQuick::ContainmentView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick15ContainmentViewE_t>.strings))
        return static_cast<void*>(this);
    return PlasmaQuick::QuickViewSharedEngine::qt_metacast(_clname);
}

int PlasmaQuick::ContainmentView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmaQuick::QuickViewSharedEngine::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PlasmaQuick::ContainmentView::locationChanged(Plasma::Types::Location _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlasmaQuick::ContainmentView::formFactorChanged(Plasma::Types::FormFactor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PlasmaQuick::ContainmentView::containmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlasmaQuick::ContainmentView::screenGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
